isqueeze Une interface pour lecteur squeezeBox sur Rpi
========================================================================

isqueeze.py :	Interface 
SBClient.py	:	lien avec serveur squeezeBox (via pylms)
	
Installation :
	sudo python setup.py install
	
	




	